netapp_ontap.models.nvme_namespace_status API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.nvme_namespace_status`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class NvmeNamespaceStatusSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the NvmeNamespaceStatus object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `container_state GET`

    The state of the volume and aggregate that contain the NVMe namespace. Namespaces are only available when their containers are available.

    Valid choices:

    - online
    - aggregate_offline
    - volume_offline
  `mapped GET`

    Reports if the NVMe namespace is mapped to an NVMe subsystem.
    There is an added cost to retrieving this property's value. It is not populated for either a collection GET or an instance GET unless it is explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more.

  `read_only GET`

    Reports if the NVMe namespace allows only read access.

  `state GET`

    The state of the NVMe namespace. Normal states for a namespace are online and offline. Other states indicate errors.

    Valid choices:

    - nvfail
    - offline
    - online
    - space_error